@@ -30,7 +30,7 @@ class WechatWebhookOptionsForm(forms.Form):
 class MultiWechatWebhookPlugin(notify.NotificationPlugin):
     author = 'badx'
     author_url = 'https://github.com/badx/sentry-multi-webhook'
-    version = '0.0.20'
+    version = '0.0.21'
     description = u'Sentry 企业微信 Webhook 插件'
     resource_links = [
         ('Source', 'https://github.com/badx/sentry-multi-webhook'),
@@ -45,7 +45,7 @@ class MultiWechatWebhookPlugin(notify.NotificationPlugin):
     project_conf_form = WechatWebhookOptionsForm
 
     def is_configured(self, project):
-        print("check notify_users" + bool(self.get_option('key', project)))
+        print("check notify_users" + str(bool(self.get_option('key', project))))
         return bool(self.get_option('key', project))
 
     def notify_users(self, group, event, *args, **kwargs):
